{% extends "announcements/base.html" %} {% load i18n %} {% load bootstrap_tags %} {% load url from future %} {% block body_class %}announcements{% endblock %} {% block body %}

# {% if announcement %}{% trans "Edit Announcement" %}{% else %}{% trans "Create Announcement" %}{% endif %}

{% if announcement %} {% url "announcements_update" pk=announcement.pk as post_url %} {% else %} {% url "announcements_create" as post_url %} {% endif %} {% csrf_token %} {{ form|as_bootstrap }}
{% trans "Cancel" %} {% if announcement %} {% trans "Delete" %} {% endif %}
{% endblock %}